# Job Title:Planning Engineer


## PURPOSE
- Responsible for all scheduling and planning activities as per contract requirements.
- Translate the project scope of work into activities and prepare and update project progress.

## RESPONSIBILITIES
- Prepare and update project schedule.
- Set work program and target milestones for each phase.
- Monitor critical activities and communicate.
- Prepares and submit updated schedules or budgets.
- Monitor day to day work progress.
- Delegate daily tasks as needed.
- Monitor weekly and monthly progress.
- Maintain a record of progress with notes.
- Participate in project meetings and discussions.


“We’re wired to expect the world to be brighter and more meaningful and more obviously interesting than it actually is. And when we realize that it isn’t, we start looking around for the real world.”

― Lev Grossman
